@@ -686,9 +686,13 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         cls: T.Type[ThisNodeType],
         patch: PatchType,
         resolver_with_filter: "ResolverType",
+        update_last_updated: bool = False,
         batch: Batch = None,
         given_client: edgedb.AsyncIOClient = None,
     ) -> T.Optional[ThisNodeType]:
+        if update_last_updated:
+            if "last_updated" in patch.__fields__:
+                patch.last_updated = datetime.utcnow()
         update_d = cls.build_update_d_from_patch(patch=patch)
         set_links_d = make_set_links_d(model=patch, model_d=update_d)
         if not update_d and not set_links_d:
